==> lumina-1.3.0_p1.tar.gz: lumina-1.3.0-p1/src-qt5/core/lumina-open/i18n/lumina-open_ko.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko">
<context>
    <name>LFileDialog</name>
    <message>
        <location filename="../LFileDialog.ui" line="14"/>
        <source>Open With...</source>
        <translation>다음으로 열기...</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="68"/>
        <source>Preferred</source>
        <translation>선호 사항</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="75"/>
        <source>Available</source>
        <translation>사용 가능</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="82"/>
        <source>Custom</source>
        <translation>사용자 설정</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="131"/>
        <source>Binary Location</source>
        <translation>실행 파일 위치</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="138"/>
        <source>Find</source>
        <translation>찾기</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="199"/>
        <source>Set this application as the default </source>
        <translation>이 프로그램을 기본으로 설정 </translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="221"/>
        <source>OK</source>
        <translation>확인</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="235"/>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="40"/>
        <source>(Email Link)</source>
        <translation>(이메일 링크)</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="41"/>
        <source>(Internet URL - %1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="114"/>
        <source>Audio</source>
        <translation>오디오</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="115"/>
        <source>Video</source>
        <translation>비디오</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="116"/>
        <source>Multimedia</source>
        <translation>멀티미디어</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="117"/>
        <source>Development</source>
        <translation>개발</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="118"/>
        <source>Education</source>
        <translation>교육</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="119"/>
        <source>Game</source>
        <translation>게임</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="120"/>
        <source>Graphics</source>
        <translation>그래픽</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="121"/>
        <source>Network</source>
        <translation>네트워크</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="122"/>
        <source>Office</source>
        <translation>업무</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="123"/>
        <source>Science</source>
        <translation>과학</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="124"/>
        <source>Settings</source>
        <translation>설정</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="125"/>
        <source>System</source>
        <translation>시스템</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="126"/>
        <source>Utilities</source>
        <translation>도구</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="127"/>
        <source>Other</source>
        <translation>기타</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="211"/>
        <source>[default] </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="278"/>
        <source>Find Application Binary</source>
        <translation>프로그램 실행 파일 찾기</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>File Error</source>
        <translation>파일 오류</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="191"/>
        <location filename="../main.cpp" line="197"/>
        <source>Audio Volume %1%</source>
        <translation>오디오 볼륨 %1%</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="205"/>
        <location filename="../main.cpp" line="214"/>
        <source>Screen Brightness %1%</source>
        <translation>화면 밝기 %1%</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="246"/>
        <source>Invalid file or URL: %1</source>
        <translation>잘못된 파일이나 URL: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="267"/>
        <source>Application entry is invalid: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="278"/>
        <source>Application shortcut is missing the launching information (malformed shortcut): %1</source>
        <translation>프로그램 바로 가기에 실행 정보가 없습니다 (잘못된 바로 가기): %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="291"/>
        <source>URL shortcut is missing the URL: %1</source>
        <translation>URL 바로 가기에 URL이 없습니다: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="302"/>
        <source>Directory shortcut is missing the path to the directory: %1</source>
        <translation>디렉터리 바로 가기에 디렉터리 경로가 없습니다: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="307"/>
        <source>Unknown type of shortcut : %1</source>
        <translation>알 수 없는 종류의 바로 가기: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="370"/>
        <source>Binary Missing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="370"/>
        <source>Could not find &quot;%1&quot;. Please ensure it is installed first.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="421"/>
        <source>Application Error</source>
        <translation>프로그램 오류</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="421"/>
        <source>The following application experienced an error and needed to close:</source>
        <translation>다음의 프로그램에 오류가 발생하여 종료하였습니다:</translation>
    </message>
</context>
</TS>

==> lumina-1.4.0_p1.tar.gz: lumina-1.4.0-p1/src-qt5/core/lumina-open/i18n/lumina-open_ko.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko">
<context>
    <name>LFileDialog</name>
    <message>
        <location filename="../LFileDialog.ui" line="14"/>
        <source>Open With...</source>
        <translation>다음으로 열기...</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="68"/>
        <source>Preferred</source>
        <translation>선호 사항</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="75"/>
        <source>Available</source>
        <translation>사용 가능</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="82"/>
        <source>Custom</source>
        <translation>사용자 설정</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="131"/>
        <source>Binary Location</source>
        <translation>실행 파일 위치</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="138"/>
        <source>Find</source>
        <translation>찾기</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="199"/>
        <source>Set this application as the default </source>
        <translation>이 프로그램을 기본으로 설정 </translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="221"/>
        <source>OK</source>
        <translation>확인</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="235"/>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="40"/>
        <source>(Email Link)</source>
        <translation>(이메일 링크)</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="41"/>
        <source>(Internet URL - %1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="114"/>
        <source>Audio</source>
        <translation>오디오</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="115"/>
        <source>Video</source>
        <translation>비디오</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="116"/>
        <source>Multimedia</source>
        <translation>멀티미디어</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="117"/>
        <source>Development</source>
        <translation>개발</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="118"/>
        <source>Education</source>
        <translation>교육</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="119"/>
        <source>Game</source>
        <translation>게임</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="120"/>
        <source>Graphics</source>
        <translation>그래픽</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="121"/>
        <source>Network</source>
        <translation>네트워크</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="122"/>
        <source>Office</source>
        <translation>업무</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="123"/>
        <source>Science</source>
        <translation>과학</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="124"/>
        <source>Settings</source>
        <translation>설정</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="125"/>
        <source>System</source>
        <translation>시스템</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="126"/>
        <source>Utilities</source>
        <translation>도구</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="127"/>
        <source>Other</source>
        <translation>기타</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="211"/>
        <source>[default] </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="278"/>
        <source>Find Application Binary</source>
        <translation>프로그램 실행 파일 찾기</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>File Error</source>
        <translation>파일 오류</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="191"/>
        <location filename="../main.cpp" line="197"/>
        <source>Audio Volume %1%</source>
        <translation>오디오 볼륨 %1%</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="205"/>
        <location filename="../main.cpp" line="214"/>
        <source>Screen Brightness %1%</source>
        <translation>화면 밝기 %1%</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="246"/>
        <source>Invalid file or URL: %1</source>
        <translation>잘못된 파일이나 URL: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="267"/>
        <source>Application entry is invalid: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="278"/>
        <source>Application shortcut is missing the launching information (malformed shortcut): %1</source>
        <translation>프로그램 바로 가기에 실행 정보가 없습니다 (잘못된 바로 가기): %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="291"/>
        <source>URL shortcut is missing the URL: %1</source>
        <translation>URL 바로 가기에 URL이 없습니다: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="302"/>
        <source>Directory shortcut is missing the path to the directory: %1</source>
        <translation>디렉터리 바로 가기에 디렉터리 경로가 없습니다: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="307"/>
        <source>Unknown type of shortcut : %1</source>
        <translation>알 수 없는 종류의 바로 가기: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="370"/>
        <source>Could not find &quot;%1&quot;. Please ensure it is installed first.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="419"/>
        <source>Application Error</source>
        <translation>프로그램 오류</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="419"/>
        <source>The following application experienced an error and needed to close:</source>
        <translation>다음의 프로그램에 오류가 발생하여 종료하였습니다:</translation>
    </message>
</context>
<context>
    <name>XDGDesktopList</name>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="608"/>
        <source>Multimedia</source>
        <translation type="unfinished">멀티미디어</translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="609"/>
        <source>Development</source>
        <translation type="unfinished">개발</translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="610"/>
        <source>Education</source>
        <translation type="unfinished">교육</translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="611"/>
        <source>Games</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="612"/>
        <source>Graphics</source>
        <translation type="unfinished">그래픽</translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="613"/>
        <source>Network</source>
        <translation type="unfinished">네트워크</translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="614"/>
        <source>Office</source>
        <translation type="unfinished">업무</translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="615"/>
        <source>Science</source>
        <translation type="unfinished">과학</translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="616"/>
        <source>Settings</source>
        <translation type="unfinished">설정</translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="617"/>
        <source>System</source>
        <translation type="unfinished">시스템</translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="618"/>
        <source>Utility</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="619"/>
        <source>Wine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="620"/>
        <source>Unsorted</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
